from datetime import datetime
from concurrent.futures import ThreadPoolExecutor
import dataiku
import dataikuapi
import requests
import pandas as pd
import ast
import time
import hashlib
import json
from webaiku.apis.dataiku.api import dataiku_api

def get_matches_nbs():
    dataset = dataiku.Dataset('match_summary_by_conclusion')
    dataset_df = dataset.get_dataframe()
    pending_nb = dataset_df[dataset_df["original_dataset"] == "remaining_pending_matches"]["count"].iloc[0] if not dataset_df[dataset_df["original_dataset"] == "remaining_pending_matches"].empty else 0
    manual_nb = dataset_df[dataset_df["original_dataset"] == "manually_matched"]["count"].iloc[0] if not dataset_df[dataset_df["original_dataset"] == "manually_matched"].empty else 0
    return {"manual": int(manual_nb), "pending": int(pending_nb)}

def get_primary_id_name():
    dataset = dataiku.Dataset('webapp_dataset')
    dataset_df = dataset.get_dataframe()
    id_name = dataset_df.columns[0]
    return {"primary_id_name": id_name}

def get_secondary_id_name():
    dataset = dataiku.Dataset('webapp_dataset')
    dataset_df = dataset.get_dataframe()
    id_name = dataset_df.columns[1]
    return {"secondary_id_name": id_name}

def get_id_list():
    dataset = dataiku.Dataset('webapp_dataset')
    dataset_df = dataset.get_dataframe()
    id_list = dataset_df[dataset_df.columns[0]].astype(str).tolist()
    id_list = list(set(id_list))
    id_list.sort()  # Sort the list of IDs
    return{"id_list":id_list}

def get_id_occurrences():
    dataset = dataiku.Dataset('webapp_dataset')
    dataset_df = dataset.get_dataframe()
    # Get the first column (assuming it contains the IDs)
    id_series = dataset_df[dataset_df.columns[0]].astype(str)
    # Count occurrences of each ID
    id_occurrences = id_series.value_counts().to_dict()
    return id_occurrences

def get_keys():
    client = dataiku.api_client()
    # Get project name and project
    project_name = dataiku_api.project_key
    project = client.get_project(project_name)
    # Get variables
    variables = project.get_variables()
    # project, variables = get_current_project_and_variables()
    global_vars = variables['standard']
    primary_keys = [global_vars['primary_column_1']]
    secondary_keys = [global_vars['secondary_column_1']]
    key_types = [global_vars['type_1']]
    thresholds = [global_vars['matching_distance_threshold_1']]
    weights = [global_vars['matching_distance_weight_1']]
    for i in range(2, 6):
        if global_vars['add_key_{}'.format(i)]:
            primary_keys.append(global_vars['primary_column_{}'.format(i)])
            secondary_keys.append(global_vars['secondary_column_{}'.format(i)])
            key_types.append(global_vars['type_{}'.format(i)])
            thresholds.append(global_vars['matching_distance_threshold_{}'.format(i)])
            weights.append(global_vars['matching_distance_weight_{}'.format(i)])
        else:
            break
    return {"primary_keys": primary_keys,
            "secondary_keys":secondary_keys,
            "key_types":key_types,
            "thresholds":thresholds,
            "weights":weights}

def get_extra_cols():
    project = dataiku.api_client().get_project(dataiku.get_custom_variables()["projectKey"])
    variables = project.get_variables()
    extra_cols_primary = variables['standard']["extra_cols_primary"]
    extra_cols_secondary = variables['standard']["extra_cols_secondary"]
    return {"extra_cols_primary": extra_cols_primary, "extra_cols_secondary": extra_cols_secondary}

def generate_unique_id(input_string, length=8):
    # Get the current timestamp and concatenate it with the input string
    timestamp = str(time.time()) + input_string
    # Hash the concatenated string using SHA-256 and take the first `length` characters
    hashed_id = hashlib.sha256(timestamp.encode()).hexdigest()[:length]
    return hashed_id
    
def get_cell_value_change(input_payload, headers):
    # Load the current edit log data
    dataset = dataiku.Dataset('editlog')
    editlog_df = dataset.get_dataframe()

    # Extract fields from the payload
    celltype = input_payload.get("celltype")
    newvalue = input_payload.get("newvalue")
    oldvalue = input_payload.get("oldvalue")
    primary_id = input_payload.get("primary_id")
    secondary_id = input_payload.get("secondary_id")
    if celltype == "comment":
        match_value = ""
        comment_value = newvalue
    else:
        match_value = newvalue
        comment_value = ""

    # Generate a unique ID
    log_id = generate_unique_id(newvalue, 8)

    # Retrieve user information
    try:
        auth_info = dataiku.api_client().get_auth_info_from_browser_headers(headers)
        user = auth_info["authIdentifier"]
    except Exception as e:
        print(f"Error retrieving user: {str(e)}")
        user = "user_not_found"

    # Create a new log entry
    new_log_entry = {
        #"log_id": log_id,
        "date": datetime.now().strftime("%Y-%m-%dT%H:%M:%S"),
        "user": user,
        "primary_id": primary_id,
        "secondary_id": secondary_id,
        "match_value":match_value ,
        "comment_value": comment_value,
    }
    # Convert the new log entry into a DataFrame
    new_log_entry_df = pd.DataFrame([new_log_entry])

    # Concatenate the new entry with the existing DataFrame
    editlog_df = pd.concat([editlog_df, new_log_entry_df], ignore_index=True)

    # Append the new entry to the DataFrame and save
    dataset.write_from_dataframe(editlog_df)
    
    # Run scenario 10 
    client = dataiku.api_client()
    project_name = dataiku_api.project_key
    project = client.get_project(project_name)
    scenario = project.get_scenario("10UPDATEMATCHING")  
    scenario.run()
    
    # Return success status and log ID
    return {"status": "OK", "log_id":log_id}