import fs from 'fs';
import path from 'path';

const componentName = process.argv[3];
const folderName = process.argv[4];
const __dirname = path.dirname(new URL(import.meta.url).pathname);


// Create folder and component file inside src/components
const componentFolderPath = path.join(
    __dirname,
    "src",
    "components",
    folderName
);
if (!fs.existsSync(componentFolderPath)) {
    fs.mkdirSync(componentFolderPath, { recursive: true });
}
fs.writeFileSync(
    path.join(componentFolderPath, `${componentName}.vue`),
    `<template>\n  <div>Hello World</div>\n</template>\n\n<script lang="ts">\n import { defineComponent } from "vue";\nexport default defineComponent({\n  name: '${componentName}',\n})\n</script>\n`
);

// Create Basic.vue file inside dev/public/examples/folderName
const examplesFolderPath = path.join(
    __dirname,
    "dev",
    "public",
    "examples",
    folderName
);
if (!fs.existsSync(examplesFolderPath)) {
    fs.mkdirSync(examplesFolderPath, { recursive: true });
}
fs.writeFileSync(
    path.join(examplesFolderPath, `${componentName}.vue`),
    `<template>
    <div class="q-pa-sm">
        <${componentName} />
    </div>
    </template>`
);

// Create componentName.vue file inside dev/src/pages/core-components
const coreComponentsPath = path.join(
    __dirname,
    "dev",
    "src",
    "pages",
    "core-components"
);

const componentContent = `<template>
    <doc-page-core title="${componentName}" :description="description" :quasarUrl="quasarURL">
        <DocExample file="${folderName}/${componentName}" :title="title"/>
    </doc-page-core>
</template>

<script>
import DocExample from '../../components/DocExample.vue';
import DocPageCore from '../../components/DocPageCore.vue';

export default {
    components: {
        DocExample, 
        DocPageCore
    },
    setup() {
        const description = "The ${componentName}";
        const quasarURL = "";
        const title = "title";

        return {
            description,
            quasarURL,
            title,
        }
    }
}
</script>`;

fs.writeFileSync(
    path.join(coreComponentsPath, `${componentName}.vue`),
    componentContent
);

// Modify src/components.js file
const componentsFilePath = path.join(__dirname, "src", "components.js");
let componentsFileContent = fs.readFileSync(componentsFilePath, "utf8");
// Add import statement at the beginning of the file
componentsFileContent =
    `import ${componentName} from "./components/${folderName}/${componentName}.vue";\n` +
    componentsFileContent;
// Find and replace the export statement to add the component
componentsFileContent = componentsFileContent.replace(
    "export {",
    `export {\n  ${componentName},`
);
fs.writeFileSync(componentsFilePath, componentsFileContent);
